@@ -2222,6 +2222,245 @@ def is_link_selector(selector: str) -> bool:
     return bool(selector_match)
 
 
+def get_all_project_stylesheets(project_dir: str) -> list:
+    """returns a list of all styles and stylesheets from a project folder.
+
+    This includes styles from style tags as well as linked stylesheets.
+
+    Args:
+        project_dir: the relative link to the folder with the web docs.
+
+    Returns:
+        all_files_styles: a list of all stylesheets and style tag contents.
+    """
+    directory = project_dir
+    html_files = clerk.get_all_files_of_type(directory, "html")
+    all_files_styles = []
+    for file in html_files:
+        filename = clerk.get_file_name(file)
+        stylesheets = get_all_stylesheets_by_file(file)
+        all_files_styles.append((filename, stylesheets))
+    return all_files_styles
+
+
+def no_style_attributes_allowed_report(project_dir: str) -> list:
+    """returns a report on whether HTML docs use style attributes or not.
+
+    Only call this report if you do not allow a style attribute in an
+    HTML doc
+
+    Args:
+        project_dir: the relative link to the folder with the web docs.
+
+    Returns:
+        report: a list of all HTML docs and a pass or fail message.
+    """
+    report = []
+
+    html_files = clerk.get_all_files_of_type(project_dir, "html")
+    for file in html_files:
+        try:
+            has_style_attr = html_tools.has_style_attribute_data(file)
+        except AttributeError:
+            continue
+        if has_style_attr:
+            result = f"fail: {file} uses style attributes"
+        else:
+            result = f"pass: {file} does not use style attributes"
+        report.append(result)
+    return report
+
+
+def styles_applied_report(project_dir: str) -> list:
+    """returns a report of all files in a project folder that apply styles
+
+    This lets us know for each HTML doc if they apply styles (pass) or
+    if they do not apply styles (fail)
+
+    Args:
+        project_dir: a relative path to the project folder.
+
+    Returns:
+        report: a list of HTML docs and whether they pass or fail (pass) means
+            they did apply styles and fail is the opposite.
+    """
+    report = []
+    html_files = clerk.get_all_files_of_type(project_dir, "html")
+    for file in html_files:
+        styles = get_all_stylesheets_by_file(file)
+        if not styles:
+            results = f"fail: {file} does NOT apply CSS."
+        else:
+            results = f"pass: {file} applies CSS."
+        report.append(results)
+    return report
+
+
+def fonts_applied_report(project_dir: str, min=1, max=2) -> list:
+    """returns a report of all files in a project folder that apply font
+    families.
+
+    You can set the minimum and maximum number of fonts applied per page.
+
+    Args:
+        project_dir: the relative path to the project folder we want to check.
+        min: the minimum number of fonts applied per file.
+        max: the maximum number of fonts applied per file.
+    Returns:
+        report: a list of font data results.
+    """
+    report = []
+    all_file_data = get_styles_by_html_files(project_dir)
+    for file in all_file_data:
+        number_of_fonts = 0
+        filename = clerk.get_file_name(file.get("file"))
+        stylesheets = file.get("stylesheets")
+        font_styles = []
+        for sheet in stylesheets:
+            font_details = get_font_families(sheet)
+            number_of_fonts += len(font_details)
+            for item in font_details:
+                selector = item.get("selector")
+                family = item.get("family")
+                if "," in family:
+                    first_font = family.split(",")[0].strip()
+                else:
+                    first_font = family
+                first_font = first_font.replace("'", "")
+                first_font = first_font.replace('"', "")
+                if first_font.lower() == "times new roman":
+                    results = f"fail: {filename}: {selector} element was set "
+                    results += "to the default font"
+                elif number_of_fonts >= min and number_of_fonts <= max:
+                    results = f"pass: {filename}: {selector} element "
+                    results += f"was set to {first_font}"
+                elif number_of_fonts < min:
+                    results = f"fail: {filename} did not apply {min} fonts, "
+                    results += f"instead, it applied {number_of_fonts} fonts."
+                if results not in font_styles:
+                    font_styles.append(results)
+        # We have all font styles applied
+        if not font_styles:
+            report.append(f"fail: {filename} No modified fonts for {filename}")
+        else:
+            report += font_styles
+    if not report:
+        report.append("fail: no html files to apply font styling to")
+    return report
+
+
+def get_global_color_report(project_dir: str, level="aaa") -> list:
+    """Returns a report on which files in a project apply global colors
+
+    Args:
+        project_dir: the project folder path.
+        level: whether we are testing for Normal AAA or Normal AA
+
+    Returns:
+        report: a list of files and a pass or fail message for each."""
+    report = []
+    all_file_data = get_all_project_stylesheets(project_dir)
+    for data in all_file_data:
+        filename = data[0]
+        passes = []
+        for sheet in data[1]:
+            rules = sheet.rulesets
+            global_color_data = get_global_color_details(rules)
+            if global_color_data:
+                for item in global_color_data:
+                    file, result = get_color_data(filename, item, level)
+                    passes.append(f"pass: {file} {result}")
+        if passes:
+            details = ""
+            for detail in passes:
+                details += detail
+        else:
+            details = f"fail: {filename} does NOT apply global colors"
+        report.append(details)
+    if not report:
+        report.append("fail: no html files to apply color styles to")
+    return report
+
+
+def get_color_data(file: str, color_details: dict, level="aaa") -> tuple:
+    """returns the color contrast data on a color.
+
+    pulls out the selector, background color, text color, contrast
+    ratio, and whether it passes color contrast.
+
+    Args:
+        file: just the name of the file (not path).
+        color_details: tuple of full color & bg color details.
+        level: the level of normal text (AAA or AA).
+
+    Returns:
+        color_data: a tuple with filename and results as a string"""
+    selector = color_details.get("selector")
+    bg_color = color_details.get("background-color")
+    color = color_details.get("color")
+    contrast_ratio = color_details.get("contrast_ratio")
+    if level == "aaa":
+        passes = color_details.get("passes_normal_aaa")
+    else:
+        passes = color_details.get("passes_normal_aa")
+    if passes:
+        results = "passes global colors"
+    else:
+        results = f"{selector} {bg_color} and {color} fail with a contrast"
+        results += f" ratio of {contrast_ratio}."
+    color_data = (file, results)
+    return color_data
+
+
+def get_heading_color_report(project_dir: str) -> list:
+    """Returns a report on which files in a project apply heading colors
+
+    For now, we just want to have at least a color or background color
+    applied.
+
+    Args:
+        project_dir: the project folder path.
+
+    Returns:
+        report: a list of files and a pass or fail message for each."""
+    report = []
+    header_re = regex_patterns.get("header_selector")
+    if project_dir[-1] != "/":
+        project_dir += "/"
+    all_file_data = get_all_project_stylesheets(project_dir)
+    for file in all_file_data:
+        filename = file[0]
+        filepath = project_dir + filename
+        all_color_rules = get_all_color_rules(filepath)
+        header_selectors = []
+        for key, val in all_color_rules.items():
+            if key == "file":
+                continue
+            is_header_selector = re.findall(header_re, key)
+            if is_header_selector:
+                # we have a header selector
+                # we only need to check color
+                color_data = val
+                color_value = color_data.get("color")
+                bg_value = color_data.get("background-color")
+                if color_value:
+                    if bg_value:
+                        header_selectors.append(
+                            (filename, color_value, bg_value)
+                        )
+                    else:
+                        header_selectors.append((filename, color_value, None))
+                if bg_value:
+                    header_selectors.append((filename, None, bg_value))
+        if header_selectors:
+            report.append(f"pass: {filename} applies colors to headers")
+        else:
+            report.append(f"fail: {filename} does NOT apply colors to headers")
+    if not report:
+        report.append("fail: no html files to apply header colors to")
+    return report
+
+
 if __name__ == "__main__":
     insane_gradient = """
     -moz-radial-gradient(0% 200%, ellipse cover,
